@@ -11,9 +11,9 @@ use File::Which qw/which/;
 use Log::Any qw/$log/;
 use File::Spec::Functions qw/splitdir/;
 use POSIX ":sys_wait_h";
-use Sub::Exporter -setup => { exports => [qw/spawn run runx/], };
+use Exporter::Tidy all => [qw/spawn run runx/];
 
-our $VERSION = '0.07_3';
+our $VERSION = '0.80.1';
 our $CONFESS;
 
 sub run {
@@ -176,9 +176,6 @@ sub BUILD {
     push( @children, $self );
     $SIG{CHLD} ||= \&_reap if $self->_on_exit;
 
-    # spawn the command
-    $log->debug( scalar $self->cmdline );
-
     $self->pid( fork() );
     if ( !defined $self->pid ) {
         my $why = $!;
@@ -216,6 +213,8 @@ sub BUILD {
         exec( $self->cmdline );
     }
 
+    $log->debugf( '(PID %d) %s', $self->pid, scalar $self->cmdline );
+
     # Parent continues from here
     close $r_in;
     close $w_out;
@@ -326,9 +325,13 @@ sub _reap {
         }
 
         foreach my $child (@dead) {
+            $log->debugf( '(PID %d) exit: %d signal:%d core:%d',
+                $child->pid, $ret >> 8, $ret & 127, $ret & 128 );
+
             $child->exit( $ret >> 8 );
             $child->signal( $ret & 127 );
             $child->core( $ret & 128 );
+
             if ( my $subref = $child->_on_exit ) {
                 $subref->($child);
             }
