@@ -4,12 +4,12 @@ use warnings;
 use 5.006;
 use Moo;
 use Carp qw/croak confess/;
-use Sub::Exporter -setup => { exports => [qw/cmd_template/], };
+use Exporter::Tidy default => [qw/cmd_template/];
 use File::Spec::Functions qw/splitdir/;
 use File::Which;
 use Sys::Cmd;
 
-our $VERSION = '0.07_3';
+our $VERSION = '0.80.1';
 our $CONFESS;
 
 sub cmd_template {
